import { toJS } from "mobx";

import { LinearProgress } from "@mui/material";

import styles from "./index.module.css";
import { useMemo } from "react";
import { formatTime, storageUnitFromB } from "@/utils/util";

/*
 * @Author: 吴永生#A02208 yongsheng.wu@wholion.com
 * @Date: 2022-06-11 15:46:42
 * @LastEditors: 吴永生#A02208 yongsheng.wu@wholion.com
 * @LastEditTime: 2022-06-15 18:03:31
 * @FilePath: /bkunyun/src/views/ConsoleLayout/components/FileItem/index.tsx
 * @Description: 这是默认设置,请设置`customMade`, 打开koroFileHeader查看配置 进行设置: https://github.com/OBKoro1/koro1FileHeader/wiki/%E9%85%8D%E7%BD%AE
 */

interface IProps {
  fileItemInfo: any;
}
const FileItem = (props: IProps) => {
  const { fileItemInfo } = props;
  const itemInfo = toJS(fileItemInfo);
  const lastInfo = itemInfo?.list[itemInfo.list?.length - 1];
  const firstInfo = itemInfo?.list[0];
  const lastMsg = lastInfo?.statusMsg;

  const TimeText = useMemo(() => {
    const val = lastInfo.endTime - firstInfo.startTime;
    return formatTime(val);
  }, [firstInfo.startTime, lastInfo.endTime]);

  const text = useMemo(() => {
    let result = "";
    if (lastMsg === "上传失败") {
      result = "重新上传";
    }
    if (lastMsg === "正在上传") {
      result = "暂停";
    }
    if (lastMsg === "上传成功") {
      result = "查看文件";
    }
    return result;
  }, [itemInfo?.list, lastMsg]);

  return (
    <div className={styles.itemBox}>
      <div className={styles.leftBox}>
        <img />
        <div>
          <div>
            <b style={{ fontSize: 14 }}>{firstInfo?.name || ""}</b>
            {lastMsg === "上传失败" ? (
              <span
                className={styles.span}
                style={{ marginLeft: 16, color: "#FF4E4E" }}
              >{`(${lastMsg})`}</span>
            ) : (
              <span className={styles.span} style={{ marginLeft: 16 }}>
                {TimeText}
              </span>
            )}
          </div>
          <LinearProgress
            sx={{ width: 300, borderRadius: 2, margin: "2px 0", color: "red" }}
            variant="determinate"
            value={50}
          />
          <div>
            <span className={styles.span}>{`700MB/${storageUnitFromB(
              500000
            )}`}</span>
          </div>
        </div>
      </div>
      <div className={styles.rightBox}>{text}</div>
    </div>
  );
};

export default FileItem;
